@@ -21,7 +21,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>
 #include <QtDeclarative/QDeclarativeContext>
 
 #include "qmlapplicationviewer.h"
-#include "lunarcalendar.h"
+
+#include "controller.h"
 
 #ifdef Q_WS_MAEMO_5
 #include <QtOpenGL/QGLWidget>
@@ -34,10 +35,10 @@ int main(int argc, char *argv[])
 
      app.setApplicationVersion(APP_VERSION);
 
-    LunarCalendar lc;
+    Controller ctrller;
 
     viewer.rootContext()->setContextProperty("ROOT", &viewer);
-    viewer.rootContext()->setContextProperty("LC", &lc);
+    viewer.rootContext()->setContextProperty("Controller", &ctrller);
 
     viewer.setOrientation(QmlApplicationViewer::ScreenOrientationAuto);
     viewer.setSource(QUrl("qrc:/qml/LichViet/main.qml"));
